@@ -4,19 +4,21 @@ use base qw/App::Cmd::ArgProcessor/;
 use strict;
 use warnings;
 
+use Module::Pluggable::Object ();
+
 =head1 NAME
 
 App::Cmd - write command line apps with less suffering
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
- $Id: /my/cs/projects/app-cmd/trunk/lib/App/Cmd.pm 25139 2006-08-25T12:48:02.868748Z rjbs  $
+ $Id: /my/cs/projects/app-cmd/trunk/lib/App/Cmd.pm 25165 2006-08-26T01:30:02.849632Z rjbs  $
 
 =cut
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 =head1 SYNOPSIS
 
@@ -24,7 +26,7 @@ in F<yourcmd>:
 
   use YourApp::Cmd;
   
-  Your::Cmd->new->run;
+  Your::Cmd->run;
 
 in F<YourApp/Cmd.pm>:
 
@@ -35,6 +37,7 @@ in F<YourApp/Cmd.pm>:
 in F<YourApp/Cmd/Command/blort.pm>:
 
   package YourApp::Cmd::Command::blort;
+  use base qw(App::Cmd::Command);
   use strict; use warnings;
 
   sub opt_spec {
@@ -74,10 +77,6 @@ without having to think about most of the annoying things usually involved.
 
 For information on how to start using App::Cmd, see App::Cmd::Tutorial.
 
-=cut
-
-use Module::Pluggable::Object ();
-
 =head1 METHODS
 
 =head2 new
@@ -91,13 +90,21 @@ Valid arguments are:
 
   no_commands_plugin - if true, the command list plugin is not added
 
+  no_help_plugin     - if true, the help plugin is not added
+
   plugin_search_path - The path to search for commands in. Defaults to
-                       "YourClass::Command"
+                       results of plugin_search_path method
 
 If C<no_commands_plugin> is not given, App::Cmd::Command::commands will be
 required, and it will be registered to handle all of its command names not
 handled by other plugins.
 
+If C<no_help_plugin> is not given, App::Cmd::Command::help will be required,
+and it will be registered to handle all of its command names not handled by
+other plugins. B<Note:> "help" is the default command, so if you do not load
+the default help plugin, you should provide our own or override the
+C<default_command> method.
+
 =cut
 
 sub new {
@@ -107,97 +114,20 @@ sub new {
   
   bless $self => $class;
 }
-
-=head2 C< plugin_search_path >
-
-Returns the plugin_search_path as set.
-
-This is a method because it's fun to override it with
-
-  use constant plugin_search_path => __PACKAGE__;
-
-and stuff.
-
-=cut
-
-sub plugin_search_path {
-  my $self = shift;
-  my $class = ref $self || $self;
-  my $default = "$class\::Command";
-
-  if ( ref $self ) {
-    return $self->{plugin_search_path} ||= $default;
-  } else {
-    return $default;
-  }
-}
-
-sub _module_pluggable_options {
-  my $self = shift;
-  return ();
-}
-
-=head2 set_global_options
-
-  $app->set_global_options( { } );
-
-This is a separate method because it's more of a hook than an accessor.
-
-=cut
-
-sub set_global_options {
-  my ( $self, $opt ) = @_;
-  return $self->{global_options} = $opt;
-}
-
-=head2 global_options
-
-  if ( $cmd->app->global_options->{verbose} ) { ... }
-
-This field contains the global options.
-
-=cut
-
-sub global_options {
-	my $self = shift;
-	return $self->{global_options} ||={} if ref($self);
-  return {};
-}
-
-sub _plugins {
-  my ($self) = @_;
-
-  my $finder = Module::Pluggable::Object->new(
-    search_path => $self->plugin_search_path(),
-    $self->_module_pluggable_options(),
-  );
-
-  return $finder->plugins;
-}
-
-sub _load_default_plugin {
-  my ($self, $plugin_name, $arg, $plugin_href) = @_;
-  unless ($arg->{"no_$plugin_name\_plugin"}) {
-    my $plugin = "App::Cmd::Command::$plugin_name";
-    eval "require $plugin" or die "couldn't load $plugin: $@";
-    for ($plugin->command_names) {
-      my $command = lc $_;
-
-      $plugin_href->{$command} = $plugin unless exists $plugin_href->{$command};
-    }
-  }
-}
  
+# effectively, returns the command-to-plugin mapping guts of a Cmd
+# if called on a class or on a Cmd with no mapping, construct a new hashref
+# suitable for use as the object's mapping
 sub _command {
   my ($self, $arg) = @_;
 
-  return $self->{command} if (ref($self) and $self->{command});
+  return $self->{command} if ref $self and $self->{command};
 
   my %plugin;
   for my $plugin ($self->_plugins) {
     eval "require $plugin" or die "couldn't load $plugin: $@";
     next unless $plugin->can("command_names");
-    foreach my $command ( map { lc } $plugin->command_names) {
+    foreach my $command (map { lc } $plugin->command_names) {
       die "two plugins for command $command: $plugin and $plugin{$command}\n"
         if exists $plugin{$command};
 
@@ -210,125 +140,37 @@ sub _command {
   return \%plugin;
 }
 
-=head2 C< command_names >
-
-  my @names = $cmd->command_names;
-
-This returns the commands names which the App::Cmd object will handle.
-
-=cut
-
-sub command_names {
+sub _plugins {
   my ($self) = @_;
-  keys %{ $self->_command };
-}
 
-=head2 C< command_plugins >
-
-  my @plugins = $cmd->command_plugins;
-
-This method returns the package names of the plugins that implement the
-App::Cmd object's commands.
-
-=cut
-
-sub command_plugins {
-  my ($self) = @_;
-  my %seen = map {; $_ => 1 } values %{ $self->_command };
-  keys %seen;
-}
-
-=head2 C< plugin_for >
-
-  my $plugin = $cmd->plugin_for($command);
-
-This method returns the plugin (module) for the given command.  If no plugin
-implements the command, it returns false.
-
-=cut
-
-sub plugin_for {
-  my ($self, $command) = @_;
-  return unless exists $self->_command->{ $command };
-
-  return $self->_command->{ $command };
-}
-
-=head2 get_command
-
-  my ( $command_name, $opt, $args ) = $app->get_command( @args );
-
-Process arguments and into a command name and [optional] global options.
-
-=cut
-
-sub get_command {
-  my ($self, @args) = @_;
-
-  my ($opt, $args, %fields)
-    = $self->_process_args(\@args, $self->_global_option_processing_params);
-
-  my ($command, @rest) = @$args;
-
-  $self->{usage} = $fields{usage};
-
-  return ($command, $opt, @rest);
-}
-
-# FIXME cleanup
-
-=head2 C< usage >
-
-  print $self->app->usage->text;
-
-Returns the usage object for the global options.
-
-=cut
-
-sub usage { $_[0]{usage} };
-
-sub _usage_text {
-  my $self = shift;
-  local $@;
-  join("\n\n", eval { $self->app->_usage_text }, eval { $self->usage->text } );
-}
-
-sub _global_option_processing_params {
-  my ( $self, @args ) = @_;
-
-  return (
-    $self->usage_desc(@args),
-    $self->global_opt_spec(@args),
-    { getopt_conf => [qw/pass_through/] },
+  my $finder = Module::Pluggable::Object->new(
+    search_path => $self->plugin_search_path,
+    $self->_module_pluggable_options,
   );
+
+  return $finder->plugins;
 }
 
-=head2 C< usage_desc >
-
-The top level usage line. Looks something like
-
-  "yourapp [options] <command>"
-
-=cut
-
-sub usage_desc {
-  my $self = shift;
-  return "%c %o <command>";
+sub _module_pluggable_options {
+  # my ($self) = @_; # no point in creating these ops, just to toss $self
+  return;
 }
 
-=head2 C< global_opt_spec >
-
-Returns an empty list. Can be overridden for pre-dispatch option processing.
-This is useful for flags like --verbose.
-
-=cut
-
-sub global_opt_spec {
-  my $self = shift;
-  return ();
+# load one of the stock plugins, unless requested to squash; unlike normal
+# plugin loading, command-to-plugin  mapping conflicts are silently ignored
+sub _load_default_plugin {
+  my ($self, $plugin_name, $arg, $plugin_href) = @_;
+  unless ($arg->{"no_$plugin_name\_plugin"}) {
+    my $plugin = "App::Cmd::Command::$plugin_name";
+    eval "require $plugin" or die "couldn't load $plugin: $@";
+    for my $command (map { lc } $plugin->command_names) {
+      $plugin_href->{$command} ||= $plugin;
+    }
+  }
 }
 
-=head2 C< run >
+
+=head2 run
 
   $cmd->run;
 
@@ -347,35 +189,19 @@ sub run {
   # We should probably use Class::Default.
   $self = $self->new unless ref $self;
 
-  # 1. prepare the command object
-  my ( $cmd, $opt, @args ) = $self->prepare_command( @ARGV );
+  # prepare the command we're going to run...
+  my ($cmd, $opt, @args) = $self->prepare_command(@ARGV);
    
-  # 2. call plugin's run method, pass in opts
-  $self->execute_command( $cmd, $opt, @args );
+  # ...and then run it
+  $self->execute_command($cmd, $opt, @args);
 }
 
-=head2 C<execute_command>
+=head2 prepare_command
 
-  $app->execute_command( $cmd, $opt, $args );
+  my ($cmd, $opt, $args) = $app->execute_command(@ARGV);
 
-This method will invoke C<validate_args> and then C<run> on C<$cmd>.
-
-=cut
-
-sub execute_command {
-  my ( $self, $cmd, $opt, @args ) = @_;
-
-  $cmd->validate_args($opt, \@args);
-
-  $cmd->run($opt, \@args);
-}
-
-=head2 C<prepare_command>
-
-  my ( $cmd, $opt, $args ) = $app->execute_command( @ARGV );
-
-This method will parse the subcommand, load the plugin for it, use it to parse
-the command line options, and eventually return everything necessary to
+This method will load the plugin for the requested command, use its options to
+parse the command line arguments, and eventually return everything necessary to
 actually execute the command.
 
 =cut
@@ -383,50 +209,236 @@ actually execute the command.
 sub prepare_command {
   my ($self, @args) = @_;
 
-  # 1. figure out first-level dispatch
-  my ( $command, $opt, @sub_args ) = $self->get_command( @args );
+  # figure out first-level dispatch
+  my ($command, $opt, @sub_args) = $self->get_command(@args);
 
-  # 2. set up the global options
-  $self->set_global_options( $opt );
+  # set up the global options (which we just determined)
+  $self->set_global_options($opt);
 
-  # 2. find its plugin or else call default plugin
-  #    ...which is help by default..?
-
-  if ( defined($command) ) {
-    $self->_prepare_command( $command, $opt, @sub_args );
+  # find its plugin or else call default plugin (default default is help)
+  if ($command) {
+    $self->_prepare_command($command, $opt, @sub_args);
   } else {
-    return $self->prepare_default_command( $opt, @sub_args );
+    $self->_prepare_default_command($opt, @sub_args);
   }
 }
 
 sub _prepare_command {
-  my ( $self, $command, $opt, @args ) = @_;
-  if ( my $plugin = $self->plugin_for($command) ) {
-    $self->_plugin_prepare( $plugin, @args );
+  my ($self, $command, $opt, @args) = @_;
+  if (my $plugin = $self->plugin_for($command)) {
+    $self->_plugin_prepare($plugin, @args);
   } else {
     return $self->_bad_command($command, $opt, @args);
   }
 }
 
+sub _prepare_default_command {
+  my ($self, $opt, @sub_args) = @_;
+  $self->_prepare_command($self->default_plugin, $opt, @sub_args);
+}
+
 sub _plugin_prepare {
-  my ( $self, $plugin, @args ) = @_;
-  return $plugin->prepare( $self, @args );
+  my ($self, $plugin, @args) = @_;
+  return $plugin->prepare($self, @args);
 }
 
 sub _bad_command {
-  my ( $self, $command, $opt, @args ) = @_;
+  my ($self, $command, $opt, @args) = @_;
   print "Unrecognized command: $command.\n\nUsage:\n\n" if defined($command);
 
   # This should be class data so that, in Bizarro World, two App::Cmds will not
   # conflict.
   our $_bad++; END { exit 1 if $_bad };
-  $self->execute_command( $self->prepare_command("commands") );
+  $self->execute_command($self->prepare_command("commands"));
   exit 1;
 }
 
-sub prepare_default_command {
+=head2 default_command
+
+This method returns the name of the command to run if none is given on the
+command line.  The default default is "help"
+
+=cut
+
+sub default_command {
+  "help"
+}
+
+=head2 execute_command
+
+  $app->execute_command($cmd, $opt, $args);
+
+This method will invoke C<validate_args> and then C<run> on C<$cmd>.
+
+=cut
+
+sub execute_command {
+  my ($self, $cmd, $opt, @args) = @_;
+
+  $cmd->validate_args($opt, \@args);
+
+  $cmd->run($opt, \@args);
+}
+
+=head2 plugin_search_path
+
+This method returns the plugin_search_path as set.  The default implementation,
+if called on "YourApp::Cmd" will return "YourApp::Cmd::Command"
+
+This is a method because it's fun to override it with, for example:
+
+  use constant plugin_search_path => __PACKAGE__;
+
+=cut
+
+sub plugin_search_path {
   my $self = shift;
-  $self->prepare_command("help");
+  my $class = ref $self || $self;
+  my $default = "$class\::Command";
+
+  if (ref $self) {
+    return $self->{plugin_search_path} ||= $default;
+  } else {
+    return $default;
+  }
+}
+
+=head2 global_options
+
+  if ($cmd->app->global_options->{verbose}) { ... }
+
+This method returns the running application's global options as a hashref.  If
+there are no options specified, an empty hashref is returend.
+
+=cut
+
+sub global_options {
+	my $self = shift;
+	return $self->{global_options} ||= {} if ref $self;
+  return {};
+}
+
+=head2 set_global_options
+
+  $app->set_global_options(\%opt);
+
+This method sets the global options.
+
+=cut
+
+sub set_global_options {
+  my ($self, $opt) = @_;
+  return $self->{global_options} = $opt;
+}
+
+=head2 command_names
+
+  my @names = $cmd->command_names;
+
+This returns the commands names which the App::Cmd object will handle.
+
+=cut
+
+sub command_names {
+  my ($self) = @_;
+  keys %{ $self->_command };
+}
+
+=head2 command_plugins
+
+  my @plugins = $cmd->command_plugins;
+
+This method returns the package names of the plugins that implement the
+App::Cmd object's commands.
+
+=cut
+
+sub command_plugins {
+  my ($self) = @_;
+  my %seen = map {; $_ => 1 } values %{ $self->_command };
+  keys %seen;
+}
+
+=head2 plugin_for
+
+  my $plugin = $cmd->plugin_for($command);
+
+This method returns the plugin (module) for the given command.  If no plugin
+implements the command, it returns false.
+
+=cut
+
+sub plugin_for {
+  my ($self, $command) = @_;
+  return unless exists $self->_command->{ $command };
+
+  return $self->_command->{ $command };
+}
+
+=head2 get_command
+
+  my ($command_name, $opt, $args) = $app->get_command(@args);
+
+Process arguments and into a command name and (optional) global options.
+
+=cut
+
+sub get_command {
+  my ($self, @args) = @_;
+
+  my ($opt, $args, %fields)
+    = $self->_process_args(\@args, $self->_global_option_processing_params);
+
+  my ($command, @rest) = @$args;
+
+  $self->{usage} = $fields{usage};
+
+  return ($command, $opt, @rest);
+}
+
+sub _global_option_processing_params {
+  my ($self, @args) = @_;
+
+  return (
+    $self->usage_desc(@args),
+    $self->global_opt_spec(@args),
+    { getopt_conf => [qw/pass_through/] },
+  );
+}
+
+=head2 usage
+
+  print $self->app->usage->text;
+
+Returns the usage object for the global options.
+
+=cut
+
+sub usage { $_[0]{usage} };
+
+=head2 usage_desc
+
+The top level usage line. Looks something like
+
+  "yourapp [options] <command>"
+
+=cut
+
+sub usage_desc {
+  # my ($self) = @_; # no point in creating these ops, just to toss $self
+  return "%c %o <command>";
+}
+
+=head2 global_opt_spec
+
+Returns an empty list. Can be overridden for pre-dispatch option processing.
+This is useful for flags like --verbose.
+
+=cut
+
+sub global_opt_spec {
+  # my ($self) = @_; # no point in creating these ops, just to toss $self
+  return;
 }
 
 =head2 usage_error
@@ -438,10 +450,16 @@ Used to die with nice usage output, during C<validate_args>.
 =cut
 
 sub usage_error {
-  my ( $self, $error ) = @_;
+  my ($self, $error) = @_;
   die "$error\n\nUsage:\n\n" . $self->_usage_text;
 }
 
+sub _usage_text {
+  my ($self) = @_;
+  local $@;
+  join("\n\n", eval { $self->app->_usage_text }, eval { $self->usage->text });
+}
+
 =head1 TODO
 
 Lots of stuff!  This list isn't close to complete yet, I'm still adding to it.
