@@ -3,12 +3,11 @@ use base qw/App::Cmd::Subdispatch/;
 
 =head1 NAME
 
-App::Cmd::Subdispatch::DashedStyle - foo command --subcommand style
-subdispatching.
+App::Cmd::Subdispatch::DashedStyle - "app cmd --subcmd" style subdispatching
 
 =head1 VERSION
 
-  $Id: $
+  $Id: /my/cs/projects/app-cmd/trunk/lib/App/Cmd/Subdispatch/DashedStyle.pm 25152 2006-08-25T23:34:47.955138Z rjbs  $
 
 =cut
 
@@ -19,7 +18,7 @@ use warnings;
 
 =head2 get_command
 
-  my ( $subcommand, $opt, $args ) = $subdispatch->get_command( @args )
+  my ($subcommand, $opt, $args) = $subdispatch->get_command(@args)
 
 A version of get_command that chooses commands as options in the following
 style:
@@ -29,15 +28,16 @@ style:
 =cut
 
 sub get_command {
-	my ( $self, @args ) = @_;
+	my ($self, @args) = @_;
 
-	my ( undef, $opt, @sub_args ) = $self->App::Cmd::Command::prepare( $self->app, @args );
+	my (undef, $opt, @sub_args)
+    = $self->App::Cmd::Command::prepare($self->app, @args);
 
-	if ( my $cmd = delete $opt->{subcommand} ) {
+	if (my $cmd = delete $opt->{subcommand}) {
 		delete $opt->{$cmd}; # useless boolean
-		return ( $cmd, $opt, @sub_args );
+		return ($cmd, $opt, @sub_args);
 	} else {
-    return ( undef, $opt, @sub_args );
+    return (undef, $opt, @sub_args);
   }
 }
 
@@ -54,20 +54,18 @@ subcommands.
 =cut
 
 sub opt_spec {
-	my ( $self, $app ) = @_;
+	my ($self, $app) = @_;
 
 	my $subcommands = $self->_command;
 	my %plugins = map {
 		$_ => [ $_->command_names ],
 	} values %$subcommands;
 
-	foreach my $opt_spec ( values %plugins ) {
+	foreach my $opt_spec (values %plugins) {
 		$opt_spec = join("|", grep { /^\w/ } @$opt_spec);
 	}
 
-	my @subcommands = map {
-		[ $plugins{$_} =>  $_->abstract ],
-	} keys %plugins;
+	my @subcommands = map { [ $plugins{$_} =>  $_->abstract ] } keys %plugins;
 
 	return (
 		[ subcommand => hidden => { one_of => \@subcommands } ],
